pub struct Tnc(/* private fields */);Expand description
A local or remote TNC attached to a radio, which can send and receive frames.
Implementations
Sourceimpl Tnc
impl Tnc
Sourcepub fn open(address: &TncAddress) -> Result<Self, TncError>
pub fn open(address: &TncAddress) -> Result<Self, TncError>
Attempt to obtain a Tnc connection using the provided address.
Sourcepub fn send_frame(&self, frame: &Ax25Frame) -> Result<(), TncError>
pub fn send_frame(&self, frame: &Ax25Frame) -> Result<(), TncError>
Transmit a frame on the radio. Transmission is not guaranteed even if a
Ok result is returned.
Sourcepub fn incoming(&self) -> Receiver<Ax25FrameResult>
pub fn incoming(&self) -> Receiver<Ax25FrameResult>
Create a new Receiver<Result<Ax25Frame, TncError>>
This will receive a copy of all incoming frames.